@@ -10,7 +10,7 @@ Fiber.enhance_textarea = function(textarea, auto_height) {
 
 	window.CKEDITOR_CONFIG_TOOLBAR = window.CKEDITOR_CONFIG_TOOLBAR || [
 		['Format'],
-		window.CKEDITOR_CONFIG_STYLES_SET ? ['Styles'] : null,
+		window.CKEDITOR_CONFIG_STYLES_SET ? ['Styles'] : '-',
 		['Bold','Italic'],
 		['NumberedList','BulletedList','Outdent','Indent'],
 		['fPageLink','fFileLink','fImageLink','fCustomLink','fUnlink'],
@@ -29,6 +29,7 @@ Fiber.enhance_textarea = function(textarea, auto_height) {
 		language: LANGUAGE_CODE,
 		extraPlugins: 'fpagelink,ffilelink,fimagelink,fcustomlink,funlink,fimage,table,tabletools',
 		removePlugins: 'scayt,language,menubutton,forms,image,link',
+		extraAllowedContent: 'a[*];img[*];iframe[*];object[*];param[*];embed[*]',
 		toolbar: window.CKEDITOR_CONFIG_TOOLBAR,
 		format_tags: window.CKEDITOR_CONFIG_FORMAT_TAGS || 'p;h2;h3;h4',
 		stylesSet: window.CKEDITOR_CONFIG_STYLES_SET || null,
