@@ -11,6 +11,7 @@ from django.core.exceptions import ValidationError
 from .models import ContentItem, Page, PageContentItem
 from .utils.validators import FiberURLValidator
 from .mixins import FiberPageMixin
+from .sitemaps import FiberSitemap
 
 
 def format_list(l, must_sort=True, separator=' '):
@@ -698,4 +699,32 @@ class TestContentItem(TestCase):
 
         # - load contentitem
         content_item1 = ContentItem.objects.get(id=content_item1.id)
-        self.assertEqual(content_item1.used_on_pages_data, [dict(url='/abc/', title='p1')])
\ No newline at end of file
+        self.assertEqual(content_item1.used_on_pages_data, [dict(url='/abc/', title='p1')])
+
+class TestSitemap(TestCase):
+
+    def setUp(self):
+        """
+        Generate test data.
+        """
+        self.a = Page.objects.create(title='a')
+        self.aa = Page.objects.create(title='aa', parent=self.a, url='aa')
+
+    def test_sitemap_class(self):
+        """
+        Sitemap class should list the 2 test pages.
+        """
+
+        urls = FiberSitemap().get_urls()
+        self.assertEqual(len(urls), 2)
+
+    def test_public(self):
+        """
+        Only public pages go in the sitemap.
+        """
+
+        self.a.is_public = False
+        self.a.save()
+
+        urls = FiberSitemap().get_urls()
+        self.assertEqual(len(urls), 1)
